==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/container/guice/cassandra-guice/src/main/java/org/apache/james/modules/mailbox/ElasticSearchClientModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.mailbox;

import org.apache.james.backends.es.ClientProvider;
import org.elasticsearch.client.RestHighLevelClient;

import com.google.inject.AbstractModule;
import com.google.inject.Scopes;

public class ElasticSearchClientModule extends AbstractModule {

    @Override
    protected void configure() {
        bind(ClientProvider.class).in(Scopes.SINGLETON);
        bind(RestHighLevelClient.class).toProvider(ClientProvider.class);
    }

}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/container/guice/cassandra-guice/src/main/java/org/apache/james/modules/mailbox/ElasticSearchClientModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.mailbox;

import java.util.Set;

import org.apache.james.backends.es.ClientProvider;
import org.apache.james.backends.es.ElasticSearchHealthCheck;
import org.apache.james.backends.es.IndexName;
import org.apache.james.core.healthcheck.HealthCheck;
import org.apache.james.mailbox.elasticsearch.ElasticSearchMailboxConfiguration;
import org.apache.james.quota.search.elasticsearch.ElasticSearchQuotaConfiguration;
import org.elasticsearch.client.RestHighLevelClient;

import com.google.common.collect.ImmutableSet;
import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import com.google.inject.Scopes;
import com.google.inject.Singleton;
import com.google.inject.multibindings.Multibinder;

public class ElasticSearchClientModule extends AbstractModule {

    @Override
    protected void configure() {
        bind(ClientProvider.class).in(Scopes.SINGLETON);
        bind(RestHighLevelClient.class).toProvider(ClientProvider.class);

        Multibinder.newSetBinder(binder(), HealthCheck.class)
            .addBinding()
            .to(ElasticSearchHealthCheck.class);
    }

    @Provides
    @Singleton
    Set<IndexName> provideIndexNames(ElasticSearchMailboxConfiguration mailboxConfiguration,
                                     ElasticSearchQuotaConfiguration quotaConfiguration) {
        return ImmutableSet.of(
            mailboxConfiguration.getIndexMailboxName(),
            quotaConfiguration.getIndexQuotaRatioName());
    }
}
